from fantasynames.hobbit import hobbit
from fantasynames.elf import elf
from fantasynames.french import french
from fantasynames.anglo import anglo
from fantasynames.dwarf import dwarf
from fantasynames.human_diverse import human
